AdmobService class
Inheritance
Object
GetLifeCycle
DisposableInterface
GetxService
AdmobService
Properties
appOpenAdUnitId
↔ AdmobUnitId
getter/setter pair
bannerAds
↔ RxMap<AdmobUnitId , BannerAd >
getter/setter pair
debugAd
→ bool
no setter
enableAd
→ bool
no setter
hashCode
→ int
The hash code for this object.
no setter inherited
initialized
→ bool
Checks whether the controller has already been initialized.
no setter inherited
isAppOpenAdAvailable
→ bool
Whether an ad is available to be shown.
no setter
isClosed
→ bool
Checks whether the controller has already been closed.
no setter inherited
loadedAds
↔ RxMap<AdmobUnitId , bool >
getter/setter pair
maxCacheDuration
→ Duration
Maximum duration allowed between loading and showing the ad.
final
onDelete
→ InternalFinalCallback<void >
Internal callback that starts the cycle of this controller.
final inherited
onStart
→ InternalFinalCallback<void >
Called at the exact moment the widget is allocated in memory.
It uses an internal "callable" type, to avoid any @overrides in subclases.
This method should be internal and is required to define the
lifetime cycle of the subclass.
final inherited
runtimeType
→ Type
A representation of the runtime type of the object.
no setter inherited
Methods
$configureLifeCycle ()
→ void
inherited
getAdUnitId (AdmobUnitId adValue )
→ String
getAppOpenAdUnitId ()
→ String
init ({required List <AdmobUnitId > adUnitIds , required AdmobUnitId appOpenAdUnitId })
→ Future <AdmobService >
loadAllAds (int width )
→ Future <void >
noSuchMethod (Invocation invocation )
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onClose ()
→ void
Called before onDelete method. onClose might be used to
dispose resources used by the controller. Like closing events,
or streams before the controller is destroyed.
Or dispose objects that can potentially create some memory leaks,
like TextEditingControllers, AnimationControllers.
Might be useful as well to persist some data on disk.
override
onInit ()
→ void
Called immediately after the widget is allocated in memory.
You might use this to initialize something for the controller.
inherited
onReady ()
→ void
Called 1 frame after onInit(). It is the perfect place to enter
navigation events, like snackbar, dialogs, or a new route, or
async request.
inherited
showAppOpenAdIfAvailable ()
→ void
Shows the ad, if one exists and is not already being shown.
toString ()
→ String
A string representation of this object.
inherited